@@ -25,19 +25,22 @@
 #include <JavaScriptCore/JavaScript.h>
 #include <glib.h>
 #include <glib-object.h>
+#include <gmodule.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <girepository.h>
 #include <ffi.h>
 
 typedef struct _SeedEngine SeedEngine;
-typedef JSValueRef SeedValue;
 
 struct _SeedEngine {
-    JSGlobalContextRef context;
-    JSObjectRef global;
+	JSGlobalContextRef context;
+	JSObjectRef global;
+
+	JSContextGroupRef group;
 };
 
+#include "seed-debug.h"
 #include "seed-engine.h"
 #include "seed-types.h"
 #include "seed-signals.h"
@@ -45,5 +48,6 @@ struct _SeedEngine {
 #include "seed-structs.h"
 #include "seed-closure.h"
 #include "seed-gtype.h"
+#include "seed-exceptions.h"
 
 #endif
